summaryrefslogtreecommitdiff
path: root/src/gnu_and_bola_-_the_libre_beat_em_up_game/scripts/bola/frames.lua
diff options
context:
space:
mode:
Diffstat (limited to 'src/gnu_and_bola_-_the_libre_beat_em_up_game/scripts/bola/frames.lua')
-rw-r--r--src/gnu_and_bola_-_the_libre_beat_em_up_game/scripts/bola/frames.lua8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/gnu_and_bola_-_the_libre_beat_em_up_game/scripts/bola/frames.lua b/src/gnu_and_bola_-_the_libre_beat_em_up_game/scripts/bola/frames.lua
index 77999e6..2f8ba5f 100644
--- a/src/gnu_and_bola_-_the_libre_beat_em_up_game/scripts/bola/frames.lua
+++ b/src/gnu_and_bola_-_the_libre_beat_em_up_game/scripts/bola/frames.lua
@@ -1,5 +1,7 @@
return {
- stand = # character.bola.stand,
- walk = # character.bola.walk,
- crouch = # character.bola.crouch,
+ stand = # character.bola.stand,
+ walk = # character.bola.walk,
+ crouchDown = # character.bola.crouchDown,
+ crouch = # character.bola.crouch,
+ standUp = # character.bola.standUp,
}